@@ -225,11 +225,11 @@ class Changelog(object):
                     released_version_diff.extend(released_version.change_blocks[change_block].changes)
 
             for change_type in other.unreleased.change_blocks:
-                if change_type not in unreleased.change_blocks:
+                if change_type not in self.unreleased.change_blocks:
                     unreleased.change_blocks[change_type] = other.unreleased.change_blocks[change_type]
                     continue
                 for change in other.unreleased.change_blocks[change_type].changes:
-                    if change not in unreleased.change_blocks[change_type].changes:
+                    if change not in self.unreleased.change_blocks[change_type].changes:
                         unreleased.change_blocks[change_type].changes.append(change)
             res.append(unreleased)
         return res
